@@ -3,15 +3,19 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-/* FIXME: 
+/* FIXME:
    Check these declarations against the C/Fortran source code.
 */
 
 /* .Call calls */
 extern SEXP _check_nonASCII(SEXP, SEXP);
+extern SEXP _readAndConvert(SEXP, SEXP);
+extern SEXP _rollMinMax(SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"_check_nonASCII", (DL_FUNC) &_check_nonASCII, 2},
+    {"_readAndConvert", (DL_FUNC) &_readAndConvert, 2},
+    {"_rollMinMax", (DL_FUNC) &_rollMinMax, 3},
     {NULL, NULL, 0}
 };
 
